@@ -1,4 +1,4 @@
-import mock
+from unittest import mock
 
 from django.contrib.auth.models import User  # noqa
 
