@@ -1,6 +1,5 @@
 import datetime
 import logging
-import six
 
 from tastypie import fields
 
@@ -14,7 +13,7 @@ class SimpleHandler(logging.Handler):
 
 def adjust_schema(schema_dict):
     for field, field_info in schema_dict['fields'].items():
-        if isinstance(field_info['default'], six.string_types) and field_info['type'] in ('datetime', 'date',):
+        if isinstance(field_info['default'], str) and field_info['type'] in ('datetime', 'date',):
             field_info['default'] = 'The current date.'
         if isinstance(field_info['default'], (datetime.datetime, datetime.date)):
             field_info['default'] = 'The current date.'
