@@ -4,8 +4,6 @@ import pstats
 from django.contrib.auth.models import User
 from django.test import TestCase
 
-import six
-
 from core.tests.mocks import MockRequest
 
 from .models import Note
@@ -33,7 +31,7 @@ class ResourceProfilingTestCase(ProfilingTestCase):
 
         user = User.objects.create_user('foo', 'pass')
 
-        for i in six.xrange(0, 200):
+        for i in range(0, 200):
             Note.objects.create(author=user, title='Note #%s' % i,
                 slug='note-%s' % i)
 
@@ -43,5 +41,5 @@ class ResourceProfilingTestCase(ProfilingTestCase):
         get_list = self.resource.get_list
         request = self.request
 
-        for i in six.xrange(0, 50):
+        for i in range(0, 50):
             get_list(request)
