@@ -1,4 +1,4 @@
-from django.conf.urls import include, url
+from django.urls.conf import include, re_path
 
 from tastypie.api import Api
 
@@ -10,5 +10,5 @@ api.register(NoteResource())
 api.register(UserResource())
 
 urlpatterns = [
-    url(r'^api/', include(api.urls)),
+    re_path(r'^api/', include(api.urls)),
 ]
