@@ -1,9 +1,9 @@
-from settings import *  # flake8: noqa
+from settings import *  # noqa
 INSTALLED_APPS.append('django.contrib.sessions')
 INSTALLED_APPS.append('profilingtests')
 
 try:
-    import oauth_provider  # flake8: noqa
+    import oauth_provider  # noqa
     INSTALLED_APPS.append('oauth_provider')
 except ImportError:
     pass
